@@ -73,7 +73,7 @@ Gets passed a Parp::Mail object as the only parameter.
 sub categorize {
   my ($self, $m) = @_;
 
-  if ($m->was_to_old_addresses) {
+  if ($m->is_to_old_address) {
     $m->reject_mail('was to old address');
     $m->deliver_to_inbox('old_addresses');
     return 'TO_AUX';
@@ -166,7 +166,7 @@ sub is_from_daemon {
                     MESSAGE_ERROR_HANDLER               |
                     postmaster\@
                    /ix or
-       $m->env_from =~ /MAILER-DAEMON/
+       $m->env_from_addr =~ /MAILER-DAEMON/
       )
       and
       $m->subject =~ /(
@@ -260,11 +260,11 @@ sub reclassify {
   # The user's telling us that the filter_category we've just
   # calculated is wrong.
   if ($m->{filter_category} eq 'IS_SPAM') {
-    vprint "Reclassification: was incorrectly identified as spam\n";
+    vprint "Reclassification: was incorrectly identified as spam.\n";
     $m->{filter_category} = 'UNKNOWN_NOT_SPAM';
   }
   elsif ($m->{filter_category} ne 'IS_SPAM') {
-    vprint "Reclassification: was incorrectly identified as bona-fide\n";
+    vprint "Reclassification: was incorrectly identified as bona-fide.\n";
     $m->{filter_category} = 'IS_SPAM';
   }
 }
