@@ -7,6 +7,8 @@ use warnings;
 # overridding, and what their defaults are.
 use base 'Parp::Config';
 
+sub main_folder { shift->inbox('MAIN') }
+
 sub me {
   # Addresses I currently want to receive mail to
   qr/
@@ -14,6 +16,7 @@ sub me {
      (adams?|aspiers|translations|bugzilla-admin|cvs-admin)
        \@guideguide\.com                                    |
      aspiers\@cpan\.org                                     |
+     adams\@plig\.net                                       |
      .*@(adamspiers|tigerpig)\.org                          |
      adamspiers\@users\.sourceforge\.net                    |
 #    8439\@excite\.com|associate                            |
@@ -39,9 +42,10 @@ sub decoys {
   # Decoy addresses I hand out to people who I don't trust not to
   # spam me.  e-mail to these addresses still comes to me, but makes
   # for very easy filtering.
-  qr/(
-      adam-spam(-.+)?\@thelonious\.new\.ox\.ac\.uk
-     )/ix;
+  qr/
+     adam-spam(-.+)?\@thelonious\.new\.ox\.ac\.uk |
+     spam.*\@adamspiers\.org
+    /ix;
 }
 
 # Addresses similar to mine.  If an e-mail has more recipients
@@ -49,7 +53,8 @@ sub decoys {
 # which has been sent to everyone in a massive alphabetically
 # sorted list.
 sub like_me { qr/adam.*\@/ }
-       
+sub max_like_me { 3 }
+
 sub good_domains {
   # Domains I really trust
   qr/
@@ -72,13 +77,15 @@ sub good_domains {
 sub subject_buzzwords {
   # If a subject matches this, I want to see the e-mail. 
   qr/\b(
+     address.*change         |
+     change.*address         |
      cello                   |
      chess                   |
      dbm                     |
      fmscore                 |
      freshmeat               |
      guideguide              |
-     jazz                    |
+     jazz\w*                 |
 #    juggling                |
      Linux                   |
      logfilterd              |
