@@ -12,13 +12,13 @@ use base 'Parp::Filter';
 ## User-defined filtering routines.
 ##
 ## They are invoked as methods, so the first parameter is always the
-## Parp::Mail object, which contains all the information you
-## would normally need to perform standard tests on it.  For example,
-## if $m is the object, $m->subject is the subject line, and
-## $m->matches('ftc', $re) is a method which returns true if the regexp
-## $re matches any of the e-mail addresses found in the From, To, Cc
-## (or X-Mailing-List) headers.  See the Parp::Mail manual page for
-## more information.
+## Parp::Mail object, which contains all the information you would
+## normally need to perform standard tests on it.  For example, if $m
+## is the object, $m->subject is the subject line, and
+## $m->matches('ftc', $re) is a method which returns a list of any of the
+## e-mail addresses found in the From, To, Cc (or X-Mailing-List)
+## headers which the regexp $re matches.  See the Parp::Mail manual
+## page for more information.
 ##
 ## Once you have performed tests and determined what action you want
 ## to take for a given e-mail, there are some useful methods available
@@ -71,18 +71,18 @@ sub is_special_case {
     $m->deliver_to_inbox('alt_addresses');
   }
 
-  if (($m->matches('ftc', qr/buzzaway\.com\b/i))[0]) {
+  if ($m->matches('ftc', qr/buzzaway\.com\b/i)) {
     $m->accept_mail('buzz spam');
     $m->deliver_to_main;
     return 'IS_SPECIAL';
   }
 
-  if (($m->matches('ftc', qr/dpie\.com\b/i))[0]) {
+  if ($m->matches('ftc', qr/dpie\.com\b/i)) {
     $m->ditch_mail('Diamond Point spam');
     return 'IS_SPECIAL';
   }
 
-  if (($m->matches('ftc', qr/handspring\.p0\.com\b/i))[0]) {
+  if ($m->matches('ftc', qr/handspring\.p0\.com\b/i)) {
     $m->accept_mail('handspring news');
     $m->deliver_to_inbox('handspring');
     return 'IS_SPECIAL';
@@ -94,58 +94,61 @@ sub is_special_case {
     return 'IS_SPECIAL';
   }
 
-  if (($m->matches('ftc', qr/\bowner.*topica\.com\b/i))[0]) {
+  if ($m->matches('ftc', qr/\bowner.*topica\.com\b/i)) {
     $m->accept_mail('topica');
     $m->deliver_to_inbox('topica');
     return 'IS_SPECIAL';
   }
 
-  if (($m->matches('ftc', qr/\blinux-thinkpad\@topica\.com\b/i))[0]) {
+  if ($m->matches('ftc', qr/\blinux-thinkpad\@topica\.com\b/i)) {
     $m->ditch_mail('no time to read');
     return 'IS_SPECIAL';
   }
 
-  if (($m->matches('ftc', qr/\bwebring\.org\b/i))[0]) {
+  if ($m->matches('ftc', qr/\bwebring\.org\b/i)) {
     $m->accept_mail('webring.org');
     $m->deliver_to_inbox('webring');
     return 'IS_SPECIAL';
   }
 
-  if (($m->matches('ftc', qr/\bexcellnews.*excell\.to\b/i))[0]) {
+  if ($m->matches('ftc', qr/\bexcellnews.*excell\.to\b/i)) {
     $m->accept_mail('eXcell news');
     $m->deliver_to_inbox('eXcell.to');
     return 'IS_SPECIAL';
   }
 
-  if (($m->matches('ftc', qr/\bquios.*\.net\b/i))[0]) {
+  if ($m->matches('ftc', qr/\bquios.*\.net\b/i)) {
     $m->accept_mail('quios');
     $m->deliver_to_inbox('quios');
     return 'IS_SPECIAL';
   }
 
-  if (($m->matches('ftc', qr/\bgeniemail\.co\.uk\b/i))[0]) {
+  if ($m->matches('ftc', qr/\bgeniemail\.co\.uk\b/i)) {
     $m->accept_mail('BT Cellnet/Genie');
     $m->deliver_to_inbox('genie');
     return 'IS_SPECIAL';
   }
 
-  if (($m->matches('ftc',
-                   qr/\b(
-                         gc-orders.*amazon\.(com|co\.uk)                |
-                         cards-bounces.*bounces\.amazon\.(com|co\.uk)
-                      )\b/ix))[0]) {
-    $m->accept_mail('amazon.com gift certificates');
+  if ($m->matches(
+    'ftc',
+    qr/\b(
+          gc-orders.*       |
+          cards-bounces.*   |
+          .*news.*
+         )\@.*amazon\.(com|co\.uk)\b/ix))
+  {
+    $m->accept_mail('amazon.com');
     $m->deliver_to_inbox('amazon');
     return 'IS_SPECIAL';
   }
 
-  if (($m->matches('ftc', qr/(admin|noreply)\@sourceforge\.net\b/i))[0]) {
+  if ($m->matches('ftc', qr/(admin|noreply)\@sourceforge\.net\b/i)) {
     $m->accept_mail('sourceforge.net');
     $m->deliver_to_inbox('sourceforge');
     return 'IS_SPECIAL';
   }
 
-  if (($m->matches('ftc', qr/\bfreshmeat-news\@.*freshmeat\.net\b/))[0]) {
+  if ($m->matches('ftc', qr/\bfreshmeat-news\@.*freshmeat\.net\b/)) {
     $m->deliver_to_inbox('freshmeat');
 #     $m->pipe_forward('fmscore >>' . config->inbox('freshmeat'));
     return 'IS_SPECIAL';
@@ -163,7 +166,7 @@ sub is_special_case {
   }
   
   if ($m->subject =~ /headlines/i and
-      ($m->matches('ftc', qr/slashdot\.org/))[0]) {
+      $m->matches('ftc', qr/slashdot\.org/)) {
     $m->accept_mail('slashdot daily news');
     $m->deliver_to_inbox('slashdot');
     return 'IS_SPECIAL';
@@ -187,25 +190,25 @@ sub is_special_case {
     return 'IS_SPAM';
   }
 
-  if (($m->matches('ftc', qr/activesw\.com/i))[0] &&
+  if ($m->matches('ftc', qr/activesw\.com/i) &&
       $m->subject =~ /qstat/i) {
     $m->accept_mail('qstat');
     $m->deliver_to_inbox('qstat');
     return 'IS_SPECIAL';
   }
 
-  if (($m->matches('ftc', qr/ntknow\@lists\.ntk\.net/i))[0]) {
+  if ($m->matches('ftc', qr/ntknow\@lists\.ntk\.net/i)) {
     $m->accept_mail('NTK');
     $m->deliver_to_inbox('NTK');
     return 'IS_SPECIAL';
   }
 
-  if (($m->matches('ftc', qr/press.*release.*moneyworld\.co\.uk/i))[0]) {
+  if ($m->matches('ftc', qr/press.*release.*moneyworld\.co\.uk/i)) {
     $m->ditch_mail('MoneyWorld press release');
     return 'IS_SPECIAL';
   }
 
-  if (($m->matches('ftc', qr/wstearns\@pobox\.com/i))[0]) {
+  if ($m->matches('ftc', qr/wstearns\@pobox\.com/i)) {
     $m->accept_mail('buildkernel');
     $m->deliver_to_main;
     return 'IS_SPECIAL';
@@ -217,40 +220,40 @@ sub is_special_case {
     return 'IS_SPECIAL';
   }
 
-  if (($m->matches('ftc', qr/announcements\@vmware\.com|vmwarenews/i))[0]) {
+  if ($m->matches('ftc', qr/announcements\@vmware\.com|vmwarenews/i)) {
     $m->accept_mail('vmware crap');
     $m->deliver_to_inbox('vmware');
     return 'IS_SPECIAL';
   }
 
-  if (($m->matches('ftc', qr/freerealtime\.com/i))[0]) {
+  if ($m->matches('ftc', qr/freerealtime\.com/i)) {
     $m->ditch_mail('freerealtime crap');
     return 'IS_SPECIAL';
   }
 
-  if (($m->matches('ftc', qr/brainbench\.com/i))[0]) {
+  if ($m->matches('ftc', qr/brainbench\.com/i)) {
     $m->accept_mail('brainbench crap');
     $m->deliver_to_inbox('brainbench');
     return 'IS_SPECIAL';
   }
 
-  if (($m->matches('ftc', qr/setiathome/i))[0]) {
+  if ($m->matches('ftc', qr/setiathome/i)) {
     $m->accept_mail('setiathome crap');
     $m->deliver_to_inbox('setiathome');
     return 'IS_SPECIAL';
   }
 
-  if (($m->matches('ftc', qr/raxco/i))[0]) {
+  if ($m->matches('ftc', qr/raxco/i)) {
     $m->ditch_mail('Raxco crap');
     return 'IS_SPECIAL';
   }
 
-  if (($m->matches('ftc', qr/reminder.*myfamily|myfamily.*reminder/i))[0]) {
+  if ($m->matches('ftc', qr/reminder.*myfamily|myfamily.*reminder/i)) {
     $m->ditch_mail('MyFamily reminder');
     return 'IS_SPECIAL';
   }
 
-  if (($m->matches('ftc', qr/notifyservice.*myfamily/i))[0]) {
+  if ($m->matches('ftc', qr/notifyservice.*myfamily/i)) {
     $m->ditch_mail('MyFamily notification');
     return 'IS_SPECIAL';
   }
@@ -314,6 +317,7 @@ sub lists {
    'arch-announce'    => { RE => '%s.*regexps\.com' },
    'arch-users'       => { RE => '%s.*regexps\.com' },
    'arch-dev'         => { RE => '%s.*regexps\.com' },
+   'bug-arch'         => { RE => '%s.*regexps\.com' },
    'bashprompt'       => { RE => 'bash.*current\.nu' },
    'buggies'          => { RE => '%s@landfill\.tequilarista\.org' },
    'fetchmail'        => { RE => '%s-friends.*@lists\.ccil\.org' },
@@ -347,13 +351,16 @@ sub lists {
                                  'reqng.*sycore\.net' },
    'sawfish'          => { RE => 'saw(mill|fish).*(aarg\.net|eazel\.com)' },
    'sitescooper'      => { RE => '%s.*lists\.sourceforge\.net' },
-   'zsh/announce'     => { RE => 'zsh-announce.*(sunsite\.(auc\.)?dk|math\.gatech\.edu)' },
-   'zsh/users'        => { RE => 'zsh-users.*(sunsite\.(auc\.)?dk|math\.gatech\.edu)' },
-   'zsh/workers'      => { RE => 'zsh-workers.*(sunsite\.(auc\.)?dk|math\.gatech\.edu)' },
+   'vortex-bug'       => { RE => '%s' },
+   'zsh-announce'     => { RE => 'zsh-announce.*(sunsite\.(auc\.)?dk|math\.gatech\.edu)' },
+   'zsh-users'        => { RE => 'zsh-users.*(sunsite\.(auc\.)?dk|math\.gatech\.edu)' },
+   'zsh-workers'      => { RE => 'zsh-workers.*(sunsite\.(auc\.)?dk|math\.gatech\.edu)' },
 
 
    ## chatter
 
+   'fwp'              => { RE => '%s.*perl\.org' },
+   'perl-golf'        => { RE => 'golf.*perl\.org' },
    'oxford-pm'        => { RE => '%s-list.*pm\.org' },
    'london-pm'        => { RE => 'london-list.*pm\.org' },
    'unix-admin'       => { RE => '%s.*comlab\.ox(ford)?\.ac\.uk' },
@@ -404,7 +411,7 @@ sub is_list_mail {
     if (exists $lists{$list}{RE}) {
       my $RE = $lists{$list}{RE};
       $RE =~ s/%s/$list/g;
-      if (($m->matches('ftc', qr/$RE/i))[0]) {
+      if ($m->matches('ftc', qr/$RE/i)) {
         $m->{list_mail} = "belonged to list `$list' via ftc";
         $m->{list_mail_dest} = $dest;
         last;
@@ -434,7 +441,7 @@ sub is_list_mail {
     }
   }
 
-  if (($m->matches('ftc', qr/hyper\.stanford\.edu/))[0]) {
+  if ($m->matches('ftc', qr/hyper\.stanford\.edu/)) {
     my $forum = $m->header->get('X-HN-Forum');
     chomp $forum;
 
@@ -472,7 +479,7 @@ sub is_list_mail {
     
     my $gg = qr/(guideguide|mediaconsult)\.com/;
 
-    return 0 unless ($m->matches('ftc', $gg))[0];
+    return 0 unless $m->matches('ftc', $gg);
 
     if ($m->subject =~ /Faq-O-Matic Moderator Mail/) {
       if ($m->{body_scalar} =~ /^Who:\s*aspiers\@guideguide\.com\b/m) {
@@ -489,7 +496,7 @@ sub is_list_mail {
       my $RE = qr/$filter\@.*$gg/;
       $filter = 'gg-bugzilla' if $filter eq 'bugzilla-daemon';
       $filter = 'ggdev'       if $filter eq 'gg-dev';
-      if (($m->matches('ftc', $RE))[0]) {
+      if ($m->matches('ftc', $RE)) {
         $m->accept_mail("belonged to list `$filter'");
         $m->deliver_to("computer-work/$filter");
         $m->{backup} = 0;
@@ -499,7 +506,7 @@ sub is_list_mail {
     }
 
     # guideguide cvs commits
-    if (($m->matches('ftc', qr/cvs-notify/i))[0]) {
+    if ($m->matches('ftc', qr/cvs-notify/i)) {
       # keep a complete archive
       $m->accept_mail("gg-cvs-notify");
       $m->deliver_to("computer-work/gg-cvs-notify.%Y-%qq");
